@@ -63,6 +63,10 @@ class LogLine:
                     buf = ""
                     varIndex += 1
                 elif varIndex in [I_URL_E] and c == "\"":
+                    if buf[-1] == "\\":  # escaping
+                        buf += c
+                        continue
+
                     l = buf
                     if l in ["-", "\\n"]:
                         result.append("")
